@@ -27,17 +27,14 @@ S3_KEY = os.environ.get("S3_KEY", "key")
 with models.DAG(
     "example_s3_to_sftp",
     schedule_interval=None,
-    start_date=datetime(2021, 1, 1),  # Override to match your needs
+    start_date=datetime(2021, 1, 1),
     catchup=False,
 ) as dag:
-
-    # [START howto_s3_transfer_data_to_sftp]
+    # [START howto_transfer_s3_to_sftp]
     create_s3_to_sftp_job = S3ToSFTPOperator(
-        task_id="create_to_s3_sftp_job",
-        sftp_conn_id="sftp_conn_id",
+        task_id="create_s3_to_sftp_job",
         sftp_path="sftp_path",
-        s3_conn_id="s3_conn_id",
         s3_bucket=S3_BUCKET,
         s3_key=S3_KEY,
     )
-    # [END howto_s3_transfer_data_to_sftp]
+    # [END howto_transfer_s3_to_sftp]
