@@ -26,41 +26,52 @@ This module contains Base AWS Hook.
 
 import configparser
 import datetime
+import json
 import logging
-import sys
 import warnings
 from functools import wraps
-from typing import Any, Callable, Dict, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Generic, Optional, Tuple, Type, TypeVar, Union
 
 import boto3
 import botocore
 import botocore.session
 import requests
 import tenacity
+from botocore.client import ClientMeta
 from botocore.config import Config
 from botocore.credentials import ReadOnlyCredentials
+from dateutil.tz import tzlocal
 from slugify import slugify
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
-from dateutil.tz import tzlocal
-
+from airflow.compat.functools import cached_property
+from airflow.configuration import conf
 from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
 from airflow.models.connection import Connection
 from airflow.utils.log.logging_mixin import LoggingMixin
 
+BaseAwsConnection = TypeVar("BaseAwsConnection", bound=Union[boto3.client, boto3.resource])
+
+
+class BaseSessionFactory(LoggingMixin):
+    """
+    Base AWS Session Factory class to handle boto3 session creation.
+    It can handle most of the AWS supported authentication methods.
+
+    User can also derive from this class to have full control of boto3 session
+    creation or to support custom federation.
+
+    .. seealso::
+        :ref:`howto/connection:aws:session-factory`
+    """
 
-class _SessionFactory(LoggingMixin):
     def __init__(self, conn: Connection, region_name: Optional[str], config: Config) -> None:
         super().__init__()
         self.conn = conn
         self.region_name = region_name
         self.config = config
         self.extra_config = self.conn.extra_dejson
+
         self.basic_session: Optional[boto3.session.Session] = None
         self.role_arn: Optional[str] = None
 
@@ -73,6 +84,15 @@ class _SessionFactory(LoggingMixin):
                 self.extra_config["session_kwargs"],
             )
             session_kwargs = self.extra_config["session_kwargs"]
+
+        if "profile" in self.extra_config and "s3_config_file" not in self.extra_config:
+            if "profile_name" not in session_kwargs:
+                self.log.warning(
+                    "Found 'profile' without specifying 's3_config_file'. "
+                    "If required profile from AWS Shared Credentials please "
+                    "set 'profile_name' in extra 'session_kwargs'."
+                )
+
         self.basic_session = self._create_basic_session(session_kwargs=session_kwargs)
         self.role_arn = self._read_role_arn_from_extra_config()
         # If role_arn was specified then STS + assume_role
@@ -81,14 +101,18 @@ class _SessionFactory(LoggingMixin):
 
         return self._create_session_with_assume_role(session_kwargs=session_kwargs)
 
-    def _create_basic_session(self, session_kwargs: Dict[str, Any]) -> boto3.session.Session:
-        aws_access_key_id, aws_secret_access_key = self._read_credentials_from_connection()
-        aws_session_token = self.extra_config.get("aws_session_token")
+    def _get_region_name(self) -> Optional[str]:
         region_name = self.region_name
         if self.region_name is None and 'region_name' in self.extra_config:
             self.log.info("Retrieving region_name from Connection.extra_config['region_name']")
             region_name = self.extra_config["region_name"]
-        self.log.info(
+        return region_name
+
+    def _create_basic_session(self, session_kwargs: Dict[str, Any]) -> boto3.session.Session:
+        aws_access_key_id, aws_secret_access_key = self._read_credentials_from_connection()
+        aws_session_token = self.extra_config.get("aws_session_token")
+        region_name = self._get_region_name()
+        self.log.debug(
             "Creating session with aws_access_key_id=%s region_name=%s",
             aws_access_key_id,
             region_name,
@@ -104,7 +128,7 @@ class _SessionFactory(LoggingMixin):
 
     def _create_session_with_assume_role(self, session_kwargs: Dict[str, Any]) -> boto3.session.Session:
         assume_role_method = self.extra_config.get('assume_role_method', 'assume_role')
-        self.log.info("assume_role_method=%s", assume_role_method)
+        self.log.debug("assume_role_method=%s", assume_role_method)
         supported_methods = ['assume_role', 'assume_role_with_saml', 'assume_role_with_web_identity']
         if assume_role_method not in supported_methods:
             raise NotImplementedError(
@@ -129,30 +153,30 @@ class _SessionFactory(LoggingMixin):
             )
         session = botocore.session.get_session()
         session._credentials = credentials
+
         if self.basic_session is None:
             raise RuntimeError("The basic session should be created here!")
+
         region_name = self.basic_session.region_name
         session.set_config_variable("region", region_name)
+
         return boto3.session.Session(botocore_session=session, **session_kwargs)
 
     def _refresh_credentials(self) -> Dict[str, Any]:
-        self.log.info('Refreshing credentials')
+        self.log.debug('Refreshing credentials')
         assume_role_method = self.extra_config.get('assume_role_method', 'assume_role')
         sts_session = self.basic_session
+
+        if sts_session is None:
+            raise RuntimeError(
+                "Session should be initialized when refresh credentials with assume_role is used!"
+            )
+
+        sts_client = sts_session.client("sts", config=self.config)
+
         if assume_role_method == 'assume_role':
-            if sts_session is None:
-                raise RuntimeError(
-                    "Session should be initialized when refresh credentials with assume_role is used!"
-                )
-            sts_client = sts_session.client("sts", config=self.config)
             sts_response = self._assume_role(sts_client=sts_client)
         elif assume_role_method == 'assume_role_with_saml':
-            if sts_session is None:
-                raise RuntimeError(
-                    "Session should be initialized when refresh "
-                    "credentials with assume_role_with_saml is used!"
-                )
-            sts_client = sts_session.client("sts", config=self.config)
             sts_response = self._assume_role_with_saml(sts_client=sts_client)
         else:
             raise NotImplementedError(f'assume_role_method={assume_role_method} not expected')
@@ -161,7 +185,7 @@ class _SessionFactory(LoggingMixin):
             raise RuntimeError(f'sts_response_http_status={sts_response_http_status}')
         credentials = sts_response['Credentials']
         expiry_time = credentials.get('Expiration').isoformat()
-        self.log.info(f'New credentials expiry_time:{expiry_time}')
+        self.log.debug('New credentials expiry_time: %s', expiry_time)
         credentials = {
             "access_key": credentials.get("AccessKeyId"),
             "secret_key": credentials.get("SecretAccessKey"),
@@ -176,8 +200,14 @@ class _SessionFactory(LoggingMixin):
         role_arn = self.extra_config.get("role_arn")
         if role_arn is None and aws_account_id is not None and aws_iam_role is not None:
             self.log.info("Constructing role_arn from aws_account_id and aws_iam_role")
+            warnings.warn(
+                "Constructing 'role_arn' from 'aws_account_id' and 'aws_iam_role' is deprecated and "
+                "will be removed in a future releases. Please set 'role_arn' in extra config.",
+                DeprecationWarning,
+                stacklevel=3,
+            )
             role_arn = f"arn:aws:iam::{aws_account_id}:role/{aws_iam_role}"
-        self.log.info("role_arn is %s", role_arn)
+        self.log.debug("role_arn is %s", role_arn)
         return role_arn
 
     def _read_credentials_from_connection(self) -> Tuple[Optional[str], Optional[str]]:
@@ -192,14 +222,18 @@ class _SessionFactory(LoggingMixin):
             aws_secret_access_key = self.extra_config["aws_secret_access_key"]
             self.log.info("Credentials retrieved from extra_config")
         elif "s3_config_file" in self.extra_config:
+            warnings.warn(
+                "Use local credentials file is never documented and well tested. "
+                "Obtain credentials by this way deprecated and will be removed in a future releases.",
+                DeprecationWarning,
+                stacklevel=3,
+            )
             aws_access_key_id, aws_secret_access_key = _parse_s3_config(
                 self.extra_config["s3_config_file"],
                 self.extra_config.get("s3_config_format"),
                 self.extra_config.get("profile"),
             )
             self.log.info("Credentials retrieved from extra_config['s3_config_file']")
-        else:
-            self.log.info("No credentials retrieved from Connection")
         return aws_access_key_id, aws_secret_access_key
 
     def _strip_invalid_session_name_characters(self, role_session_name: str) -> str:
@@ -207,10 +241,16 @@ class _SessionFactory(LoggingMixin):
 
     def _assume_role(self, sts_client: boto3.client) -> Dict:
         assume_role_kwargs = self.extra_config.get("assume_role_kwargs", {})
-        if "external_id" in self.extra_config:  # Backwards compatibility
+        if "ExternalId" not in assume_role_kwargs and "external_id" in self.extra_config:
+            warnings.warn(
+                "'external_id' in extra config is deprecated and will be removed in a future releases. "
+                "Set 'ExternalId' in 'assume_role_kwargs' in extra config.",
+                DeprecationWarning,
+                stacklevel=3,
+            )
             assume_role_kwargs["ExternalId"] = self.extra_config.get("external_id")
         role_session_name = self._strip_invalid_session_name_characters(f"Airflow_{self.conn.conn_id}")
-        self.log.info(
+        self.log.debug(
             "Doing sts_client.assume_role to role_arn=%s (role_session_name=%s)",
             self.role_arn,
             role_session_name,
@@ -232,7 +272,7 @@ class _SessionFactory(LoggingMixin):
                 'Currently only "http_spegno_auth" is supported, and must be specified.'
             )
 
-        self.log.info("Doing sts_client.assume_role_with_saml to role_arn=%s", self.role_arn)
+        self.log.debug("Doing sts_client.assume_role_with_saml to role_arn=%s", self.role_arn)
         assume_role_kwargs = self.extra_config.get("assume_role_kwargs", {})
         return sts_client.assume_role_with_saml(
             RoleArn=self.role_arn,
@@ -245,7 +285,7 @@ class _SessionFactory(LoggingMixin):
         self, saml_config: Dict[str, Any], auth: requests.auth.AuthBase
     ) -> requests.models.Response:
         idp_url = saml_config["idp_url"]
-        self.log.info("idp_url= %s", idp_url)
+        self.log.debug("idp_url= %s", idp_url)
 
         session = requests.Session()
 
@@ -302,8 +342,8 @@ class _SessionFactory(LoggingMixin):
                 'The IDP response contains sensitive information, but log_idp_response is ON (%s).',
                 log_idp_response,
             )
-            self.log.info('idp_response.content= %s', idp_response.content)
-            self.log.info('xpath= %s', xpath)
+            self.log.debug('idp_response.content= %s', idp_response.content)
+            self.log.debug('xpath= %s', xpath)
         # Extract SAML Assertion from the returned HTML / XML
         xml = etree.fromstring(idp_response.content)
         saml_assertion = xml.xpath(xpath)
@@ -356,7 +396,7 @@ class _SessionFactory(LoggingMixin):
         return web_identity_token_loader
 
 
-class AwsBaseHook(BaseHook):
+class AwsGenericHook(BaseHook, Generic[BaseAwsConnection]):
     """
     Interact with AWS.
     This class is a thin wrapper around the boto3 python library.
@@ -366,19 +406,13 @@ class AwsBaseHook(BaseHook):
         running Airflow in a distributed manner and aws_conn_id is None or
         empty, then default boto3 configuration would be used (and must be
         maintained on each worker node).
-    :type aws_conn_id: str
-    :param verify: Whether or not to verify SSL certificates.
+    :param verify: Whether or not to verify SSL certificates. See:
         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
-    :type verify: Union[bool, str, None]
     :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
-    :type region_name: Optional[str]
     :param client_type: boto3.client client_type. Eg 's3', 'emr' etc
-    :type client_type: Optional[str]
     :param resource_type: boto3.resource resource_type. Eg 'dynamodb' etc
-    :type resource_type: Optional[str]
-    :param config: Configuration for botocore client.
-        (https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html)
-    :type config: Optional[botocore.client.Config]
+    :param config: Configuration for botocore client. See:
+        https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
     """
 
     conn_name_attr = 'aws_conn_id'
@@ -403,16 +437,13 @@ class AwsBaseHook(BaseHook):
         self.region_name = region_name
         self.config = config
 
-        if not (self.client_type or self.resource_type):
-            raise AirflowException('Either client_type or resource_type must be provided.')
-
     def _get_credentials(self, region_name: Optional[str]) -> Tuple[boto3.session.Session, Optional[str]]:
 
         if not self.aws_conn_id:
             session = boto3.session.Session(region_name=region_name)
             return session, None
 
-        self.log.info("Airflow Connection: aws_conn_id=%s", self.aws_conn_id)
+        self.log.debug("Airflow Connection: aws_conn_id=%s", self.aws_conn_id)
 
         try:
             # Fetch the Airflow connection object
@@ -420,26 +451,28 @@ class AwsBaseHook(BaseHook):
             extra_config = connection_object.extra_dejson
             endpoint_url = extra_config.get("host")
 
-            # https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html#botocore.config.Config
+            # https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
             if "config_kwargs" in extra_config:
-                self.log.info(
+                self.log.debug(
                     "Retrieving config_kwargs from Connection.extra_config['config_kwargs']: %s",
                     extra_config["config_kwargs"],
                 )
                 self.config = Config(**extra_config["config_kwargs"])
 
-            session = _SessionFactory(
+            session = SessionFactory(
                 conn=connection_object, region_name=region_name, config=self.config
             ).create_session()
 
             return session, endpoint_url
 
         except AirflowException:
-            self.log.warning("Unable to use Airflow Connection for credentials.")
-            self.log.info("Fallback on boto3 credential strategy")
-            # http://boto3.readthedocs.io/en/latest/guide/configuration.html
+            self.log.warning(
+                "Unable to use Airflow Connection for credentials. "
+                "Fallback on boto3 credential strategy. See: "
+                "https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html"
+            )
 
-        self.log.info(
+        self.log.debug(
             "Creating session using boto3 credential strategy region_name=%s",
             region_name,
         )
@@ -504,15 +537,32 @@ class AwsBaseHook(BaseHook):
         :return: boto3.client or boto3.resource
         :rtype: Union[boto3.client, boto3.resource]
         """
-        if self.client_type:
+        if not ((not self.client_type) ^ (not self.resource_type)):
+            raise ValueError(
+                f"Either client_type={self.client_type!r} or "
+                f"resource_type={self.resource_type!r} must be provided, not both."
+            )
+        elif self.client_type:
             return self.get_client_type(region_name=self.region_name)
-        elif self.resource_type:
-            return self.get_resource_type(region_name=self.region_name)
         else:
-            # Rare possibility - subclasses have not specified a client_type or resource_type
-            raise NotImplementedError('Could not get boto3 connection!')
+            return self.get_resource_type(region_name=self.region_name)
 
-    def get_conn(self) -> Union[boto3.client, boto3.resource]:
+    @cached_property
+    def conn_client_meta(self) -> ClientMeta:
+        conn = self.conn
+        if isinstance(conn, botocore.client.BaseClient):
+            return conn.meta
+        return conn.meta.client.meta
+
+    @property
+    def conn_region_name(self) -> str:
+        return self.conn_client_meta.region_name
+
+    @property
+    def conn_partition(self) -> str:
+        return self.conn_client_meta.partition
+
+    def get_conn(self) -> BaseAwsConnection:
         """
         Get the underlying boto3 client/resource (cached)
 
@@ -575,13 +625,14 @@ class AwsBaseHook(BaseHook):
                 min_limit = retry_args.get('min', 1)
                 max_limit = retry_args.get('max', 1)
                 stop_after_delay = retry_args.get('stop_after_delay', 10)
-                tenacity_logger = tenacity.before_log(self.log, logging.DEBUG) if self.log else None
+                tenacity_before_logger = tenacity.before_log(self.log, logging.INFO) if self.log else None
+                tenacity_after_logger = tenacity.after_log(self.log, logging.INFO) if self.log else None
                 default_kwargs = {
                     'wait': tenacity.wait_exponential(multiplier=multiplier, max=max_limit, min=min_limit),
                     'retry': tenacity.retry_if_exception(should_retry),
                     'stop': tenacity.stop_after_delay(stop_after_delay),
-                    'before': tenacity_logger,
-                    'after': tenacity_logger,
+                    'before': tenacity_before_logger,
+                    'after': tenacity_after_logger,
                 }
                 return tenacity.retry(**default_kwargs)(fun)(self, *args, **kwargs)
 
@@ -589,6 +640,40 @@ class AwsBaseHook(BaseHook):
 
         return retry_decorator
 
+    def test_connection(self):
+        """
+        Tests the AWS connection by call AWS STS (Security Token Service) GetCallerIdentity API.
+
+        .. seealso::
+            https://docs.aws.amazon.com/STS/latest/APIReference/API_GetCallerIdentity.html
+        """
+        orig_client_type, self.client_type = self.client_type, 'sts'
+        try:
+            res = self.get_client_type().get_caller_identity()
+            metadata = res.pop("ResponseMetadata", {})
+            if metadata.get("HTTPStatusCode") == 200:
+                return True, json.dumps(res)
+            else:
+                try:
+                    return False, json.dumps(metadata)
+                except TypeError:
+                    return False, str(metadata)
+        except Exception as e:
+            return False, str(e)
+        finally:
+            self.client_type = orig_client_type
+
+
+class AwsBaseHook(AwsGenericHook[Union[boto3.client, boto3.resource]]):
+    """
+    Interact with AWS.
+    This class is a thin wrapper around the boto3 python library
+    with basic conn annotation.
+
+    .. seealso::
+        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsGenericHook`
+    """
+
 
 def _parse_s3_config(
     config_file_name: str, config_format: Optional[str] = "boto", profile: Optional[str] = None
@@ -598,12 +683,9 @@ def _parse_s3_config(
     parse boto, s3cmd.conf and AWS SDK config formats
 
     :param config_file_name: path to the config file
-    :type config_file_name: str
     :param config_format: config type. One of "boto", "s3cmd" or "aws".
         Defaults to "boto"
-    :type config_format: str
     :param profile: profile name in AWS type config file
-    :type profile: str
     """
     config = configparser.ConfigParser()
     if config.read(config_file_name):  # pragma: no cover
@@ -642,3 +724,19 @@ def _parse_s3_config(
             logging.warning("Option Error in parsing s3 config file")
             raise
         return access_key, secret_key
+
+
+def resolve_session_factory() -> Type[BaseSessionFactory]:
+    """Resolves custom SessionFactory class"""
+    clazz = conf.getimport("aws", "session_factory", fallback=None)
+    if not clazz:
+        return BaseSessionFactory
+    if not issubclass(clazz, BaseSessionFactory):
+        raise TypeError(
+            f"Your custom AWS SessionFactory class `{clazz.__name__}` is not a subclass "
+            f"of `{BaseSessionFactory.__name__}`."
+        )
+    return clazz
+
+
+SessionFactory = resolve_session_factory()
