@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """
-A client for AWS batch services
+A client for AWS Batch services
 
 .. seealso::
 
@@ -24,7 +24,7 @@ A client for AWS batch services
     - http://boto3.readthedocs.io/en/latest/reference/services/batch.html
     - https://docs.aws.amazon.com/batch/latest/APIReference/Welcome.html
 """
-
+import warnings
 from random import uniform
 from time import sleep
 from typing import Dict, List, Optional, Union
@@ -39,10 +39,10 @@ from airflow.typing_compat import Protocol, runtime_checkable
 
 
 @runtime_checkable
-class AwsBatchProtocol(Protocol):
+class BatchProtocol(Protocol):
     """
     A structured Protocol for ``boto3.client('batch') -> botocore.client.Batch``.
-    This is used for type hints on :py:meth:`.AwsBatchClient.client`; it covers
+    This is used for type hints on :py:meth:`.BatchClient.client`; it covers
     only the subset of client methods required.
 
     .. seealso::
@@ -53,10 +53,9 @@ class AwsBatchProtocol(Protocol):
 
     def describe_jobs(self, jobs: List[str]) -> Dict:
         """
-        Get job descriptions from AWS batch
+        Get job descriptions from AWS Batch
 
         :param jobs: a list of JobId to describe
-        :type jobs: List[str]
 
         :return: an API response to describe jobs
         :rtype: Dict
@@ -70,13 +69,12 @@ class AwsBatchProtocol(Protocol):
         :param waiterName: The name of the waiter.  The name should match
             the name (including the casing) of the key name in the waiter
             model file (typically this is CamelCasing).
-        :type waiterName: str
 
-        :return: a waiter object for the named AWS batch service
+        :return: a waiter object for the named AWS Batch service
         :rtype: botocore.waiter.Waiter
 
         .. note::
-            AWS batch might not have any waiters (until botocore PR-1307 is released).
+            AWS Batch might not have any waiters (until botocore PR-1307 is released).
 
             .. code-block:: python
 
@@ -102,28 +100,21 @@ class AwsBatchProtocol(Protocol):
         tags: Dict,
     ) -> Dict:
         """
-        Submit a batch job
+        Submit a Batch job
 
-        :param jobName: the name for the AWS batch job
-        :type jobName: str
+        :param jobName: the name for the AWS Batch job
 
         :param jobQueue: the queue name on AWS Batch
-        :type jobQueue: str
 
         :param jobDefinition: the job definition name on AWS Batch
-        :type jobDefinition: str
 
         :param arrayProperties: the same parameter that boto3 will receive
-        :type arrayProperties: Dict
 
         :param parameters: the same parameter that boto3 will receive
-        :type parameters: Dict
 
         :param containerOverrides: the same parameter that boto3 will receive
-        :type containerOverrides: Dict
 
         :param tags: the same parameter that boto3 will receive
-        :type tags: Dict
 
         :return: an API response
         :rtype: Dict
@@ -132,13 +123,11 @@ class AwsBatchProtocol(Protocol):
 
     def terminate_job(self, jobId: str, reason: str) -> Dict:
         """
-        Terminate a batch job
+        Terminate a Batch job
 
         :param jobId: a job ID to terminate
-        :type jobId: str
 
         :param reason: a reason to terminate job ID
-        :type reason: str
 
         :return: an API response
         :rtype: Dict
@@ -150,17 +139,15 @@ class AwsBatchProtocol(Protocol):
 # all the Airflow wrappers of boto3 clients should not adopt invalid-names to match boto3.
 
 
-class AwsBatchClientHook(AwsBaseHook):
+class BatchClientHook(AwsBaseHook):
     """
-    A client for AWS batch services.
+    A client for AWS Batch services.
 
     :param max_retries: exponential back-off retries, 4200 = 48 hours;
         polling is only used when waiters is None
-    :type max_retries: Optional[int]
 
     :param status_retries: number of HTTP retries to get job status, 10;
         polling is only used when waiters is None
-    :type status_retries: Optional[int]
 
     .. note::
         Several methods use a default random delay to check or poll for job status, i.e.
@@ -169,17 +156,17 @@ class AwsBatchClientHook(AwsBaseHook):
         when many concurrent tasks request job-descriptions.
 
         To modify the global defaults for the range of jitter allowed when a
-        random delay is used to check batch job status, modify these defaults, e.g.:
+        random delay is used to check Batch job status, modify these defaults, e.g.:
         .. code-block::
 
-            AwsBatchClient.DEFAULT_DELAY_MIN = 0
-            AwsBatchClient.DEFAULT_DELAY_MAX = 5
+            BatchClient.DEFAULT_DELAY_MIN = 0
+            BatchClient.DEFAULT_DELAY_MAX = 5
 
         When explicit delay values are used, a 1 second random jitter is applied to the
         delay (e.g. a delay of 0 sec will be a ``random.uniform(0, 1)`` delay.  It is
         generally recommended that random jitter is added to API requests.  A
         convenience method is provided for this, e.g. to get a random delay of
-        10 sec +/- 5 sec: ``delay = AwsBatchClient.add_jitter(10, width=5, minima=0)``
+        10 sec +/- 5 sec: ``delay = BatchClient.add_jitter(10, width=5, minima=0)``
 
     .. seealso::
         - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html
@@ -214,24 +201,22 @@ class AwsBatchClientHook(AwsBaseHook):
         self.status_retries = status_retries or self.STATUS_RETRIES
 
     @property
-    def client(self) -> Union[AwsBatchProtocol, botocore.client.BaseClient]:
+    def client(self) -> Union[BatchProtocol, botocore.client.BaseClient]:
         """
-        An AWS API client for batch services.
+        An AWS API client for Batch services.
 
         :return: a boto3 'batch' client for the ``.region_name``
-        :rtype: Union[AwsBatchProtocol, botocore.client.BaseClient]
+        :rtype: Union[BatchProtocol, botocore.client.BaseClient]
         """
         return self.conn
 
     def terminate_job(self, job_id: str, reason: str) -> Dict:
         """
-        Terminate a batch job
+        Terminate a Batch job
 
         :param job_id: a job ID to terminate
-        :type job_id: str
 
         :param reason: a reason to terminate job ID
-        :type reason: str
 
         :return: an API response
         :rtype: Dict
@@ -242,11 +227,10 @@ class AwsBatchClientHook(AwsBaseHook):
 
     def check_job_success(self, job_id: str) -> bool:
         """
-        Check the final status of the batch job; return True if the job
+        Check the final status of the Batch job; return True if the job
         'SUCCEEDED', else raise an AirflowException
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
         :rtype: bool
 
@@ -256,7 +240,7 @@ class AwsBatchClientHook(AwsBaseHook):
         job_status = job.get("status")
 
         if job_status == self.SUCCESS_STATE:
-            self.log.info("AWS batch job (%s) succeeded: %s", job_id, job)
+            self.log.info("AWS Batch job (%s) succeeded: %s", job_id, job)
             return True
 
         if job_status == self.FAILURE_STATE:
@@ -269,13 +253,11 @@ class AwsBatchClientHook(AwsBaseHook):
 
     def wait_for_job(self, job_id: str, delay: Union[int, float, None] = None) -> None:
         """
-        Wait for batch job to complete
+        Wait for Batch job to complete
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
         :param delay: a delay before polling for job status
-        :type delay: Optional[Union[int, float]]
 
         :raises: AirflowException
         """
@@ -296,11 +278,9 @@ class AwsBatchClientHook(AwsBaseHook):
         changes too quickly for polling to detect a RUNNING status that moves
         quickly from STARTING to RUNNING to completed (often a failure).
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
         :param delay: a delay before polling for job status
-        :type delay: Optional[Union[int, float]]
 
         :raises: AirflowException
         """
@@ -316,11 +296,9 @@ class AwsBatchClientHook(AwsBaseHook):
         So the status options that this will wait for are the transitions from:
         'SUBMITTED'>'PENDING'>'RUNNABLE'>'STARTING'>'RUNNING'>'SUCCEEDED'|'FAILED'
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
         :param delay: a delay before polling for job status
-        :type delay: Optional[Union[int, float]]
 
         :raises: AirflowException
         """
@@ -332,12 +310,10 @@ class AwsBatchClientHook(AwsBaseHook):
         """
         Poll for job status using an exponential back-off strategy (with max_retries).
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
-        :param match_status: a list of job status to match; the batch job status are:
+        :param match_status: a list of job status to match; the Batch job status are:
             'SUBMITTED'|'PENDING'|'RUNNABLE'|'STARTING'|'RUNNING'|'SUCCEEDED'|'FAILED'
-        :type match_status: List[str]
 
         :rtype: bool
 
@@ -376,8 +352,7 @@ class AwsBatchClientHook(AwsBaseHook):
         """
         Get job description (using status_retries).
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
         :return: an API response for describe jobs
         :rtype: Dict
@@ -419,11 +394,9 @@ class AwsBatchClientHook(AwsBaseHook):
         """
         Parse job description to extract description for job_id
 
-        :param job_id: a batch job ID
-        :type job_id: str
+        :param job_id: a Batch job ID
 
         :param response: an API response for describe jobs
-        :type response: Dict
 
         :return: an API response to describe job_id
         :rtype: Dict
@@ -437,6 +410,45 @@ class AwsBatchClientHook(AwsBaseHook):
 
         return matching_jobs[0]
 
+    def get_job_awslogs_info(self, job_id: str) -> Optional[Dict[str, str]]:
+        """
+        Parse job description to extract AWS CloudWatch information.
+
+        :param job_id: AWS Batch Job ID
+        """
+        job_container_desc = self.get_job_description(job_id=job_id).get("container", {})
+        log_configuration = job_container_desc.get("logConfiguration", {})
+
+        # In case if user select other "logDriver" rather than "awslogs"
+        # than CloudWatch logging should be disabled.
+        # If user not specify anything than expected that "awslogs" will use
+        # with default settings:
+        #   awslogs-group = /aws/batch/job
+        #   awslogs-region = `same as AWS Batch Job region`
+        log_driver = log_configuration.get("logDriver", "awslogs")
+        if log_driver != "awslogs":
+            self.log.warning(
+                "AWS Batch job (%s) uses logDriver (%s). AWS CloudWatch logging disabled.", job_id, log_driver
+            )
+            return None
+
+        awslogs_stream_name = job_container_desc.get("logStreamName")
+        if not awslogs_stream_name:
+            # In case of call this method on very early stage of running AWS Batch
+            # there is possibility than AWS CloudWatch Stream Name not exists yet.
+            # AWS CloudWatch Stream Name also not created in case of misconfiguration.
+            self.log.warning("AWS Batch job (%s) doesn't create AWS CloudWatch Stream.", job_id)
+            return None
+
+        # Try to get user-defined log configuration options
+        log_options = log_configuration.get("options", {})
+
+        return {
+            "awslogs_stream_name": awslogs_stream_name,
+            "awslogs_group": log_options.get("awslogs-group", "/aws/batch/job"),
+            "awslogs_region": log_options.get("awslogs-region", self.conn_region_name),
+        }
+
     @staticmethod
     def add_jitter(
         delay: Union[int, float], width: Union[int, float] = 1, minima: Union[int, float] = 0
@@ -445,20 +457,17 @@ class AwsBatchClientHook(AwsBaseHook):
         Use delay +/- width for random jitter
 
         Adding jitter to status polling can help to avoid
-        AWS batch API limits for monitoring batch jobs with
+        AWS Batch API limits for monitoring Batch jobs with
         a high concurrency in Airflow tasks.
 
         :param delay: number of seconds to pause;
             delay is assumed to be a positive number
-        :type delay: Union[int, float]
 
         :param width: delay +/- width for random jitter;
             width is assumed to be a positive number
-        :type width: Union[int, float]
 
         :param minima: minimum delay allowed;
             minima is assumed to be a non-negative number
-        :type minima: Union[int, float]
 
         :return: uniform(delay - width, delay + width) jitter
             and it is a non-negative number
@@ -478,7 +487,6 @@ class AwsBatchClientHook(AwsBaseHook):
 
         :param delay: a delay to pause execution using ``time.sleep(delay)``;
             a small 1 second jitter is applied to the delay.
-        :type delay: Optional[Union[int, float]]
 
         .. note::
             This method uses a default random delay, i.e.
@@ -487,9 +495,9 @@ class AwsBatchClientHook(AwsBaseHook):
             when many concurrent tasks request job-descriptions.
         """
         if delay is None:
-            delay = uniform(AwsBatchClientHook.DEFAULT_DELAY_MIN, AwsBatchClientHook.DEFAULT_DELAY_MAX)
+            delay = uniform(BatchClientHook.DEFAULT_DELAY_MIN, BatchClientHook.DEFAULT_DELAY_MAX)
         else:
-            delay = AwsBatchClientHook.add_jitter(delay)
+            delay = BatchClientHook.add_jitter(delay)
         sleep(delay)
 
     @staticmethod
@@ -500,7 +508,6 @@ class AwsBatchClientHook(AwsBaseHook):
         This is used in the :py:meth:`.poll_for_job_status` method.
 
         :param tries: Number of tries
-        :type tries: int
 
         :rtype: float
 
@@ -538,3 +545,35 @@ class AwsBatchClientHook(AwsBaseHook):
         delay = 1 + pow(tries * 0.6, 2)
         delay = min(max_interval, delay)
         return uniform(delay / 3, delay)
+
+
+class AwsBatchProtocol(BatchProtocol, Protocol):
+    """
+    This class is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchProtocol`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This class is deprecated. "
+            "Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchProtocol`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
+
+
+class AwsBatchClientHook(BatchClientHook):
+    """
+    This hook is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchClientHook`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This hook is deprecated. "
+            "Please use :class:`airflow.providers.amazon.aws.hooks.batch.BatchClientHook`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
