@@ -20,7 +20,7 @@ from typing import Any, Dict, List, Optional
 
 from botocore.exceptions import ClientError
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
 
@@ -41,8 +41,8 @@ class EmrHook(AwsBaseHook):
     conn_type = 'emr'
     hook_name = 'Amazon Elastic MapReduce'
 
-    def __init__(self, emr_conn_id: Optional[str] = default_conn_name, *args, **kwargs) -> None:
-        self.emr_conn_id = emr_conn_id
+    def __init__(self, emr_conn_id: str = default_conn_name, *args, **kwargs) -> None:
+        self.emr_conn_id: str = emr_conn_id
         kwargs["client_type"] = "emr"
         super().__init__(*args, **kwargs)
 
@@ -78,12 +78,11 @@ class EmrHook(AwsBaseHook):
         run_job_flow method.
         Overrides for this config may be passed as the job_flow_overrides.
         """
-        if not self.emr_conn_id:
-            raise AirflowException('emr_conn_id must be present to use create_job_flow')
-
-        emr_conn = self.get_connection(self.emr_conn_id)
-
-        config = emr_conn.extra_dejson.copy()
+        try:
+            emr_conn = self.get_connection(self.emr_conn_id)
+            config = emr_conn.extra_dejson.copy()
+        except AirflowNotFoundException:
+            config = {}
         config.update(job_flow_overrides)
 
         response = self.get_conn().run_job_flow(**config)
@@ -133,6 +132,7 @@ class EmrContainerHook(AwsBaseHook):
         job_driver: dict,
         configuration_overrides: Optional[dict] = None,
         client_request_token: Optional[str] = None,
+        tags: Optional[dict] = None,
     ) -> str:
         """
         Submit a job to the EMR Containers API and return the job ID.
@@ -148,6 +148,7 @@ class EmrContainerHook(AwsBaseHook):
             specifically either application configuration or monitoring configuration.
         :param client_request_token: The client idempotency token of the job run request.
             Use this if you want to specify a unique ID to prevent two jobs from getting started.
+        :param tags: The tags assigned to job runs.
         :return: Job ID
         """
         params = {
@@ -157,6 +158,7 @@ class EmrContainerHook(AwsBaseHook):
             "releaseLabel": release_label,
             "jobDriver": job_driver,
             "configurationOverrides": configuration_overrides or {},
+            "tags": tags or {},
         }
         if client_request_token:
             params["clientToken"] = client_request_token
