@@ -29,25 +29,15 @@ class GlueJobHook(AwsBaseHook):
     Interact with AWS Glue - create job, trigger, crawler
 
     :param s3_bucket: S3 bucket where logs and local etl script will be uploaded
-    :type s3_bucket: Optional[str]
     :param job_name: unique job name per AWS account
-    :type job_name: Optional[str]
     :param desc: job description
-    :type desc: Optional[str]
     :param concurrent_run_limit: The maximum number of concurrent runs allowed for a job
-    :type concurrent_run_limit: int
     :param script_location: path to etl script on s3
-    :type script_location: Optional[str]
     :param retry_limit: Maximum number of times to retry this job if it fails
-    :type retry_limit: int
     :param num_of_dpus: Number of AWS Glue DPUs to allocate to this Job
-    :type num_of_dpus: int
     :param region_name: aws region name (example: us-east-1)
-    :type region_name: Optional[str]
     :param iam_role_name: AWS IAM Role for Glue Job Execution
-    :type iam_role_name: Optional[str]
     :param create_job_kwargs: Extra arguments for Glue Job Creation
-    :type create_job_kwargs: Optional[dict]
     """
 
     JOB_POLL_INTERVAL = 6  # polls job status after every JOB_POLL_INTERVAL seconds
@@ -128,8 +118,8 @@ class GlueJobHook(AwsBaseHook):
 
         try:
             job_name = self.get_or_create_glue_job()
-            job_run = glue_client.start_job_run(JobName=job_name, Arguments=script_arguments, **run_kwargs)
-            return job_run
+            return glue_client.start_job_run(JobName=job_name, Arguments=script_arguments, **run_kwargs)
+
         except Exception as general_error:
             self.log.error("Failed to run aws glue job, error: %s", general_error)
             raise
@@ -139,15 +129,12 @@ class GlueJobHook(AwsBaseHook):
         Get state of the Glue job. The job state can be
         running, finished, failed, stopped or timeout.
         :param job_name: unique job name per AWS account
-        :type job_name: str
         :param run_id: The job-run ID of the predecessor job run
-        :type run_id: str
         :return: State of the Glue job
         """
         glue_client = self.get_conn()
         job_run = glue_client.get_job_run(JobName=job_name, RunId=run_id, PredecessorsIncluded=True)
-        job_run_state = job_run['JobRun']['JobRunState']
-        return job_run_state
+        return job_run['JobRun']['JobRunState']
 
     def job_completion(self, job_name: str, run_id: str) -> Dict[str, str]:
         """
@@ -155,9 +142,7 @@ class GlueJobHook(AwsBaseHook):
         fails and return final state if finished.
         Raises AirflowException when the job failed
         :param job_name: unique job name per AWS account
-        :type job_name: str
         :param run_id: The job-run ID of the predecessor job run
-        :type run_id: str
         :return: Dict of JobRunState and JobRunId
         """
         failed_states = ['FAILED', 'TIMEOUT']
@@ -169,7 +154,7 @@ class GlueJobHook(AwsBaseHook):
                 self.log.info("Exiting Job %s Run State: %s", run_id, job_run_state)
                 return {'JobRunState': job_run_state, 'JobRunId': run_id}
             if job_run_state in failed_states:
-                job_error_message = "Exiting Job " + run_id + " Run State: " + job_run_state
+                job_error_message = f"Exiting Job {run_id} Run State: {job_run_state}"
                 self.log.info(job_error_message)
                 raise AirflowException(job_error_message)
             else:
@@ -196,6 +181,12 @@ class GlueJobHook(AwsBaseHook):
             s3_log_path = f's3://{self.s3_bucket}/{self.s3_glue_logs}{self.job_name}'
             execution_role = self.get_iam_execution_role()
             try:
+                default_command = {
+                    "Name": "glueetl",
+                    "ScriptLocation": self.script_location,
+                }
+                command = self.create_job_kwargs.pop("Command", default_command)
+
                 if "WorkerType" in self.create_job_kwargs and "NumberOfWorkers" in self.create_job_kwargs:
                     create_job_response = glue_client.create_job(
                         Name=self.job_name,
@@ -203,7 +194,7 @@ class GlueJobHook(AwsBaseHook):
                         LogUri=s3_log_path,
                         Role=execution_role['Role']['Arn'],
                         ExecutionProperty={"MaxConcurrentRuns": self.concurrent_run_limit},
-                        Command={"Name": "glueetl", "ScriptLocation": self.script_location},
+                        Command=command,
                         MaxRetries=self.retry_limit,
                         **self.create_job_kwargs,
                     )
@@ -214,7 +205,7 @@ class GlueJobHook(AwsBaseHook):
                         LogUri=s3_log_path,
                         Role=execution_role['Role']['Arn'],
                         ExecutionProperty={"MaxConcurrentRuns": self.concurrent_run_limit},
-                        Command={"Name": "glueetl", "ScriptLocation": self.script_location},
+                        Command=command,
                         MaxRetries=self.retry_limit,
                         MaxCapacity=self.num_of_dpus,
                         **self.create_job_kwargs,
