@@ -1,4 +1,3 @@
-#
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -26,65 +25,63 @@ An Airflow operator for AWS Batch services
     - http://boto3.readthedocs.io/en/latest/reference/services/batch.html
     - https://docs.aws.amazon.com/batch/latest/APIReference/Welcome.html
 """
+import warnings
 from typing import TYPE_CHECKING, Any, Optional, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
-from airflow.providers.amazon.aws.hooks.batch_client import AwsBatchClientHook
+from airflow.providers.amazon.aws.hooks.batch_client import BatchClientHook
+from airflow.providers.amazon.aws.links.batch import (
+    BatchJobDefinitionLink,
+    BatchJobDetailsLink,
+    BatchJobQueueLink,
+)
+from airflow.providers.amazon.aws.links.logs import CloudWatchEventsLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class AwsBatchOperator(BaseOperator):
+class BatchOperator(BaseOperator):
     """
     Execute a job on AWS Batch
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:BatchOperator`
+
     :param job_name: the name for the job that will run on AWS Batch (templated)
-    :type job_name: str
 
     :param job_definition: the job definition name on AWS Batch
-    :type job_definition: str
 
     :param job_queue: the queue name on AWS Batch
-    :type job_queue: str
 
     :param overrides: the `containerOverrides` parameter for boto3 (templated)
-    :type overrides: Optional[dict]
 
     :param array_properties: the `arrayProperties` parameter for boto3
-    :type array_properties: Optional[dict]
 
     :param parameters: the `parameters` for boto3 (templated)
-    :type parameters: Optional[dict]
 
     :param job_id: the job ID, usually unknown (None) until the
         submit_job operation gets the jobId defined by AWS Batch
-    :type job_id: Optional[str]
 
-    :param waiters: an :py:class:`.AwsBatchWaiters` object (see note below);
+    :param waiters: an :py:class:`.BatchWaiters` object (see note below);
         if None, polling is used with max_retries and status_retries.
-    :type waiters: Optional[AwsBatchWaiters]
 
     :param max_retries: exponential back-off retries, 4200 = 48 hours;
         polling is only used when waiters is None
-    :type max_retries: int
 
     :param status_retries: number of HTTP retries to get job status, 10;
         polling is only used when waiters is None
-    :type status_retries: int
 
     :param aws_conn_id: connection id of AWS credentials / region name. If None,
         credential boto3 strategy will be used.
-    :type aws_conn_id: str
 
     :param region_name: region name to use in AWS Hook.
         Override the region_name in connection (if provided)
-    :type region_name: str
 
     :param tags: collection of tags to apply to the AWS Batch job submission
         if None, no tags are submitted
-    :type tags: dict
 
     .. note::
         Any custom waiters must return a waiter for these calls:
@@ -104,6 +101,15 @@ class AwsBatchOperator(BaseOperator):
     )
     template_fields_renderers = {"overrides": "json", "parameters": "json"}
 
+    @property
+    def operator_extra_links(self):
+        op_extra_links = [BatchJobDetailsLink(), BatchJobDefinitionLink(), BatchJobQueueLink()]
+        if not self.array_properties:
+            # There is no CloudWatch Link to the parent Batch Job available.
+            op_extra_links.append(CloudWatchEventsLink())
+
+        return tuple(op_extra_links)
+
     def __init__(
         self,
         *,
@@ -133,7 +139,7 @@ class AwsBatchOperator(BaseOperator):
         self.parameters = parameters or {}
         self.waiters = waiters
         self.tags = tags or {}
-        self.hook = AwsBatchClientHook(
+        self.hook = BatchClientHook(
             max_retries=max_retries,
             status_retries=status_retries,
             aws_conn_id=aws_conn_id,
@@ -176,13 +182,24 @@ class AwsBatchOperator(BaseOperator):
                 containerOverrides=self.overrides,
                 tags=self.tags,
             )
-            self.job_id = response["jobId"]
-
-            self.log.info("AWS Batch job (%s) started: %s", self.job_id, response)
         except Exception as e:
-            self.log.error("AWS Batch job (%s) failed submission", self.job_id)
+            self.log.error(
+                "AWS Batch job failed submission - job definition: %s - on queue %s",
+                self.job_definition,
+                self.job_queue,
+            )
             raise AirflowException(e)
 
+        self.job_id = response["jobId"]
+        self.log.info("AWS Batch job (%s) started: %s", self.job_id, response)
+        BatchJobDetailsLink.persist(
+            context=context,
+            operator=self,
+            region_name=self.hook.conn_region_name,
+            aws_partition=self.hook.conn_partition,
+            job_id=self.job_id,
+        )
+
     def monitor_job(self, context: 'Context'):
         """
         Monitor an AWS Batch job
@@ -195,10 +212,65 @@ class AwsBatchOperator(BaseOperator):
         if not self.job_id:
             raise AirflowException('AWS Batch job - job_id was not found')
 
+        try:
+            job_desc = self.hook.get_job_description(self.job_id)
+            job_definition_arn = job_desc["jobDefinition"]
+            job_queue_arn = job_desc["jobQueue"]
+            self.log.info(
+                "AWS Batch job (%s) Job Definition ARN: %r, Job Queue ARN: %r",
+                self.job_id,
+                job_definition_arn,
+                job_queue_arn,
+            )
+        except KeyError:
+            self.log.warning("AWS Batch job (%s) can't get Job Definition ARN and Job Queue ARN", self.job_id)
+        else:
+            BatchJobDefinitionLink.persist(
+                context=context,
+                operator=self,
+                region_name=self.hook.conn_region_name,
+                aws_partition=self.hook.conn_partition,
+                job_definition_arn=job_definition_arn,
+            )
+            BatchJobQueueLink.persist(
+                context=context,
+                operator=self,
+                region_name=self.hook.conn_region_name,
+                aws_partition=self.hook.conn_partition,
+                job_queue_arn=job_queue_arn,
+            )
+
         if self.waiters:
             self.waiters.wait_for_job(self.job_id)
         else:
             self.hook.wait_for_job(self.job_id)
 
+        awslogs = self.hook.get_job_awslogs_info(self.job_id)
+        if awslogs:
+            self.log.info("AWS Batch job (%s) CloudWatch Events details found: %s", self.job_id, awslogs)
+            CloudWatchEventsLink.persist(
+                context=context,
+                operator=self,
+                region_name=self.hook.conn_region_name,
+                aws_partition=self.hook.conn_partition,
+                **awslogs,
+            )
+
         self.hook.check_job_success(self.job_id)
         self.log.info("AWS Batch job (%s) succeeded", self.job_id)
+
+
+class AwsBatchOperator(BatchOperator):
+    """
+    This operator is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.operators.batch.BatchOperator`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This operator is deprecated. "
+            "Please use :class:`airflow.providers.amazon.aws.operators.batch.BatchOperator`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
