@@ -16,53 +16,44 @@
 # specific language governing permissions and limitations
 # under the License.
 import ast
-import sys
-from datetime import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
 from uuid import uuid4
 
+from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator, BaseOperatorLink, TaskInstance
-from airflow.providers.amazon.aws.hooks.emr import EmrHook
+from airflow.models import BaseOperator
+from airflow.providers.amazon.aws.hooks.emr import EmrContainerHook, EmrHook
+from airflow.providers.amazon.aws.links.emr import EmrClusterLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
-from airflow.providers.amazon.aws.hooks.emr import EmrContainerHook
-
-
 class EmrAddStepsOperator(BaseOperator):
     """
     An operator that adds steps to an existing EMR job_flow.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EmrAddStepsOperator`
+
     :param job_flow_id: id of the JobFlow to add steps to. (templated)
-    :type job_flow_id: Optional[str]
     :param job_flow_name: name of the JobFlow to add steps to. Use as an alternative to passing
         job_flow_id. will search for id of JobFlow with matching name in one of the states in
         param cluster_states. Exactly one cluster like this should exist or will fail. (templated)
-    :type job_flow_name: Optional[str]
     :param cluster_states: Acceptable cluster states when searching for JobFlow id by job_flow_name.
         (templated)
-    :type cluster_states: list
     :param aws_conn_id: aws connection to uses
-    :type aws_conn_id: str
     :param steps: boto3 style steps or reference to a steps file (must be '.json') to
         be added to the jobflow. (templated)
-    :type steps: list|str
     :param do_xcom_push: if True, job_flow_id is pushed to XCom with key job_flow_id.
-    :type do_xcom_push: bool
     """
 
     template_fields: Sequence[str] = ('job_flow_id', 'job_flow_name', 'cluster_states', 'steps')
     template_ext: Sequence[str] = ('.json',)
     template_fields_renderers = {"steps": "json"}
     ui_color = '#f9c915'
+    operator_extra_links = (EmrClusterLink(),)
 
     def __init__(
         self,
@@ -74,8 +65,6 @@ class EmrAddStepsOperator(BaseOperator):
         steps: Optional[Union[List[dict], str]] = None,
         **kwargs,
     ):
-        if kwargs.get('xcom_push') is not None:
-            raise AirflowException("'xcom_push' was deprecated, use 'do_xcom_push' instead")
         if not (job_flow_id is None) ^ (job_flow_name is None):
             raise AirflowException('Exactly one of job_flow_id or job_flow_name must be specified.')
         super().__init__(**kwargs)
@@ -102,6 +91,14 @@ class EmrAddStepsOperator(BaseOperator):
         if self.do_xcom_push:
             context['ti'].xcom_push(key='job_flow_id', value=job_flow_id)
 
+        EmrClusterLink.persist(
+            context=context,
+            operator=self,
+            region_name=emr_hook.conn_region_name,
+            aws_partition=emr_hook.conn_partition,
+            job_flow_id=job_flow_id,
+        )
+
         self.log.info('Adding steps to %s', job_flow_id)
 
         # steps may arrive as a string representing a list
@@ -123,30 +120,27 @@ class EmrContainerOperator(BaseOperator):
     """
     An operator that submits jobs to EMR on EKS virtual clusters.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EmrContainerOperator`
+
     :param name: The name of the job run.
-    :type name: str
     :param virtual_cluster_id: The EMR on EKS virtual cluster ID
-    :type virtual_cluster_id: str
     :param execution_role_arn: The IAM role ARN associated with the job run.
-    :type execution_role_arn: str
     :param release_label: The Amazon EMR release version to use for the job run.
-    :type release_label: str
     :param job_driver: Job configuration details, e.g. the Spark job parameters.
-    :type job_driver: dict
     :param configuration_overrides: The configuration overrides for the job run,
         specifically either application configuration or monitoring configuration.
-    :type configuration_overrides: dict
     :param client_request_token: The client idempotency token of the job run request.
         Use this if you want to specify a unique ID to prevent two jobs from getting started.
         If no token is provided, a UUIDv4 token will be generated for you.
-    :type client_request_token: str
     :param aws_conn_id: The Airflow connection used for AWS credentials.
-    :type aws_conn_id: str
+    :param wait_for_completion: Whether or not to wait in the operator for the job to complete.
     :param poll_interval: Time (in seconds) to wait between two consecutive calls to check query status on EMR
-    :type poll_interval: int
     :param max_tries: Maximum number of times to wait for the job run to finish.
         Defaults to None, which will poll until the job is *not* in a pending, submitted, or running state.
-    :type max_tries: int
+    :param tags: The tags assigned to job runs.
+        Defaults to None
     """
 
     template_fields: Sequence[str] = (
@@ -169,8 +163,10 @@ class EmrContainerOperator(BaseOperator):
         configuration_overrides: Optional[dict] = None,
         client_request_token: Optional[str] = None,
         aws_conn_id: str = "aws_default",
+        wait_for_completion: bool = True,
         poll_interval: int = 30,
         max_tries: Optional[int] = None,
+        tags: Optional[dict] = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -182,9 +178,11 @@ class EmrContainerOperator(BaseOperator):
         self.configuration_overrides = configuration_overrides or {}
         self.aws_conn_id = aws_conn_id
         self.client_request_token = client_request_token or str(uuid4())
+        self.wait_for_completion = wait_for_completion
         self.poll_interval = poll_interval
         self.max_tries = max_tries
-        self.job_id = None
+        self.tags = tags
+        self.job_id: Optional[str] = None
 
     @cached_property
     def hook(self) -> EmrContainerHook:
@@ -203,20 +201,22 @@ class EmrContainerOperator(BaseOperator):
             self.job_driver,
             self.configuration_overrides,
             self.client_request_token,
+            self.tags,
         )
-        query_status = self.hook.poll_query_status(self.job_id, self.max_tries, self.poll_interval)
+        if self.wait_for_completion:
+            query_status = self.hook.poll_query_status(self.job_id, self.max_tries, self.poll_interval)
 
-        if query_status in EmrContainerHook.FAILURE_STATES:
-            error_message = self.hook.get_job_failure_reason(self.job_id)
-            raise AirflowException(
-                f"EMR Containers job failed. Final state is {query_status}. "
-                f"query_execution_id is {self.job_id}. Error: {error_message}"
-            )
-        elif not query_status or query_status in EmrContainerHook.INTERMEDIATE_STATES:
-            raise AirflowException(
-                f"Final state of EMR Containers job is {query_status}. "
-                f"Max tries of poll status exceeded, query_execution_id is {self.job_id}."
-            )
+            if query_status in EmrContainerHook.FAILURE_STATES:
+                error_message = self.hook.get_job_failure_reason(self.job_id)
+                raise AirflowException(
+                    f"EMR Containers job failed. Final state is {query_status}. "
+                    f"query_execution_id is {self.job_id}. Error: {error_message}"
+                )
+            elif not query_status or query_status in EmrContainerHook.INTERMEDIATE_STATES:
+                raise AirflowException(
+                    f"Final state of EMR Containers job is {query_status}. "
+                    f"Max tries of poll status exceeded, query_execution_id is {self.job_id}."
+                )
 
         return self.job_id
 
@@ -241,43 +241,26 @@ class EmrContainerOperator(BaseOperator):
                     self.hook.poll_query_status(self.job_id)
 
 
-class EmrClusterLink(BaseOperatorLink):
-    """Operator link for EmrCreateJobFlowOperator. It allows users to access the EMR Cluster"""
-
-    name = 'EMR Cluster'
-
-    def get_link(self, operator: BaseOperator, dttm: datetime) -> str:
-        """
-        Get link to EMR cluster.
-
-        :param operator: operator
-        :param dttm: datetime
-        :return: url link
-        """
-        ti = TaskInstance(task=operator, execution_date=dttm)
-        flow_id = ti.xcom_pull(task_ids=operator.task_id)
-        return (
-            f'https://console.aws.amazon.com/elasticmapreduce/home#cluster-details:{flow_id}'
-            if flow_id
-            else ''
-        )
-
-
 class EmrCreateJobFlowOperator(BaseOperator):
     """
     Creates an EMR JobFlow, reading the config from the EMR connection.
     A dictionary of JobFlow overrides can be passed that override
     the config from the connection.
 
-    :param aws_conn_id: aws connection to uses
-    :type aws_conn_id: str
-    :param emr_conn_id: emr connection to use
-    :type emr_conn_id: str
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EmrCreateJobFlowOperator`
+
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is None or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node)
+    :param emr_conn_id: emr connection to use for run_job_flow request body.
+        This will be overridden by the job_flow_overrides param
     :param job_flow_overrides: boto3 style arguments or reference to an arguments file
         (must be '.json') to override emr_connection extra. (templated)
-    :type job_flow_overrides: dict|str
     :param region_name: Region named passed to EmrHook
-    :type region_name: Optional[str]
     """
 
     template_fields: Sequence[str] = ('job_flow_overrides',)
@@ -322,32 +305,40 @@ class EmrCreateJobFlowOperator(BaseOperator):
         if not response['ResponseMetadata']['HTTPStatusCode'] == 200:
             raise AirflowException(f'JobFlow creation failed: {response}')
         else:
-            self.log.info('JobFlow with id %s created', response['JobFlowId'])
-            return response['JobFlowId']
+            job_flow_id = response['JobFlowId']
+            self.log.info('JobFlow with id %s created', job_flow_id)
+            EmrClusterLink.persist(
+                context=context,
+                operator=self,
+                region_name=emr.conn_region_name,
+                aws_partition=emr.conn_partition,
+                job_flow_id=job_flow_id,
+            )
+            return job_flow_id
 
 
 class EmrModifyClusterOperator(BaseOperator):
     """
     An operator that modifies an existing EMR cluster.
+
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EmrModifyClusterOperator`
+
     :param cluster_id: cluster identifier
-    :type cluster_id: str
     :param step_concurrency_level: Concurrency of the cluster
-    :type step_concurrency_level: int
     :param aws_conn_id: aws connection to uses
-    :type aws_conn_id: str
     :param do_xcom_push: if True, cluster_id is pushed to XCom with key cluster_id.
-    :type do_xcom_push: bool
     """
 
     template_fields: Sequence[str] = ('cluster_id', 'step_concurrency_level')
     template_ext: Sequence[str] = ()
     ui_color = '#f9c915'
+    operator_extra_links = (EmrClusterLink(),)
 
     def __init__(
         self, *, cluster_id: str, step_concurrency_level: int, aws_conn_id: str = 'aws_default', **kwargs
     ):
-        if kwargs.get('xcom_push') is not None:
-            raise AirflowException("'xcom_push' was deprecated, use 'do_xcom_push' instead")
         super().__init__(**kwargs)
         self.aws_conn_id = aws_conn_id
         self.cluster_id = cluster_id
@@ -355,12 +346,19 @@ class EmrModifyClusterOperator(BaseOperator):
 
     def execute(self, context: 'Context') -> int:
         emr_hook = EmrHook(aws_conn_id=self.aws_conn_id)
-
         emr = emr_hook.get_conn()
 
         if self.do_xcom_push:
             context['ti'].xcom_push(key='cluster_id', value=self.cluster_id)
 
+        EmrClusterLink.persist(
+            context=context,
+            operator=self,
+            region_name=emr_hook.conn_region_name,
+            aws_partition=emr_hook.conn_partition,
+            job_flow_id=self.cluster_id,
+        )
+
         self.log.info('Modifying cluster %s', self.cluster_id)
         response = emr.modify_cluster(
             ClusterId=self.cluster_id, StepConcurrencyLevel=self.step_concurrency_level
@@ -377,15 +375,18 @@ class EmrTerminateJobFlowOperator(BaseOperator):
     """
     Operator to terminate EMR JobFlows.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EmrTerminateJobFlowOperator`
+
     :param job_flow_id: id of the JobFlow to terminate. (templated)
-    :type job_flow_id: str
     :param aws_conn_id: aws connection to uses
-    :type aws_conn_id: str
     """
 
     template_fields: Sequence[str] = ('job_flow_id',)
     template_ext: Sequence[str] = ()
     ui_color = '#f9c915'
+    operator_extra_links = (EmrClusterLink(),)
 
     def __init__(self, *, job_flow_id: str, aws_conn_id: str = 'aws_default', **kwargs):
         super().__init__(**kwargs)
@@ -393,7 +394,16 @@ class EmrTerminateJobFlowOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
 
     def execute(self, context: 'Context') -> None:
-        emr = EmrHook(aws_conn_id=self.aws_conn_id).get_conn()
+        emr_hook = EmrHook(aws_conn_id=self.aws_conn_id)
+        emr = emr_hook.get_conn()
+
+        EmrClusterLink.persist(
+            context=context,
+            operator=self,
+            region_name=emr_hook.conn_region_name,
+            aws_partition=emr_hook.conn_partition,
+            job_flow_id=self.job_flow_id,
+        )
 
         self.log.info('Terminating JobFlow %s', self.job_flow_id)
         response = emr.terminate_job_flows(JobFlowIds=[self.job_flow_id])
