@@ -19,21 +19,24 @@
 
 import ast
 import json
-import sys
+import re
+import warnings
 from typing import Optional
 from urllib.parse import urlencode
 
 import boto3
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
+from airflow.compat.functools import cached_property
+from airflow.providers.amazon.aws.utils import get_airflow_version
 from airflow.secrets import BaseSecretsBackend
 from airflow.utils.log.logging_mixin import LoggingMixin
 
 
+def _parse_version(val):
+    val = re.sub(r'(\d+\.\d+\.\d+).*', lambda x: x.group(1), val)
+    return tuple(int(x) for x in val.split('.'))
+
+
 class SecretsManagerBackend(BaseSecretsBackend, LoggingMixin):
     """
     Retrieves Connection or Variables from AWS Secrets Manager
@@ -125,7 +128,7 @@ class SecretsManagerBackend(BaseSecretsBackend, LoggingMixin):
         self.profile_name = profile_name
         self.sep = sep
         self.full_url_mode = full_url_mode
-        self.extra_conn_words = extra_conn_words if extra_conn_words else {}
+        self.extra_conn_words = extra_conn_words or {}
         self.kwargs = kwargs
 
     @cached_property
@@ -169,13 +172,11 @@ class SecretsManagerBackend(BaseSecretsBackend, LoggingMixin):
 
         conn_string = "{conn_type}://{user}:{password}@{host}:{port}/{schema}".format(**conn_d)
 
-        connection = self._format_uri_with_extra(secret, conn_string)
+        return self._format_uri_with_extra(secret, conn_string)
 
-        return connection
-
-    def get_conn_uri(self, conn_id: str):
+    def get_conn_value(self, conn_id: str):
         """
-        Get Connection Value
+        Get serialized representation of Connection
 
         :param conn_id: connection id
         """
@@ -184,20 +185,37 @@ class SecretsManagerBackend(BaseSecretsBackend, LoggingMixin):
 
         if self.full_url_mode:
             return self._get_secret(self.connections_prefix, conn_id)
-        else:
-            try:
-                secret_string = self._get_secret(self.connections_prefix, conn_id)
-                # json.loads gives error
-                secret = ast.literal_eval(secret_string) if secret_string else None
-            except ValueError:  # 'malformed node or string: ' error, for empty conns
-                connection = None
-                secret = None
+        try:
+            secret_string = self._get_secret(self.connections_prefix, conn_id)
+            # json.loads gives error
+            secret = ast.literal_eval(secret_string) if secret_string else None
+        except ValueError:  # 'malformed node or string: ' error, for empty conns
+            connection = None
+            secret = None
 
-            # These lines will check if we have with some denomination stored an username, password and host
-            if secret:
-                connection = self.get_uri_from_secret(secret)
+        # These lines will check if we have with some denomination stored an username, password and host
+        if secret:
+            connection = self.get_uri_from_secret(secret)
 
-            return connection
+        return connection
+
+    def get_conn_uri(self, conn_id: str) -> Optional[str]:
+        """
+        Return URI representation of Connection conn_id.
+
+        As of Airflow version 2.3.0 this method is deprecated.
+
+        :param conn_id: the connection id
+        :return: deserialized Connection
+        """
+        if get_airflow_version() >= (2, 3):
+            warnings.warn(
+                f"Method `{self.__class__.__name__}.get_conn_uri` is deprecated and will be removed "
+                "in a future release.  Please use method `get_conn_value` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        return self.get_conn_value(conn_id)
 
     def get_variable(self, key: str) -> Optional[str]:
         """
@@ -227,6 +245,7 @@ class SecretsManagerBackend(BaseSecretsBackend, LoggingMixin):
         :param path_prefix: Prefix for the Path to get Secret
         :param secret_id: Secret Key
         """
+        error_msg = "An error occurred when calling the get_secret_value operation"
         if path_prefix:
             secrets_path = self.build_path(path_prefix, secret_id, self.sep)
         else:
@@ -239,15 +258,36 @@ class SecretsManagerBackend(BaseSecretsBackend, LoggingMixin):
             return response.get('SecretString')
         except self.client.exceptions.ResourceNotFoundException:
             self.log.debug(
-                "An error occurred (ResourceNotFoundException) when calling the "
-                "get_secret_value operation: "
-                "Secret %s not found.",
+                "ResourceNotFoundException: %s. Secret %s not found.",
+                error_msg,
                 secret_id,
             )
             return None
-        except self.client.exceptions.AccessDeniedException:
+        except self.client.exceptions.InvalidParameterException:
             self.log.debug(
-                "An error occurred (AccessDeniedException) when calling the get_secret_value operation",
+                "InvalidParameterException: %s",
+                error_msg,
+                exc_info=True,
+            )
+            return None
+        except self.client.exceptions.InvalidRequestException:
+            self.log.debug(
+                "InvalidRequestException: %s",
+                error_msg,
+                exc_info=True,
+            )
+            return None
+        except self.client.exceptions.DecryptionFailure:
+            self.log.debug(
+                "DecryptionFailure: %s",
+                error_msg,
+                exc_info=True,
+            )
+            return None
+        except self.client.exceptions.InternalServiceError:
+            self.log.debug(
+                "InternalServiceError: %s",
+                error_msg,
                 exc_info=True,
             )
             return None
