@@ -16,10 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-
+import fnmatch
 import os
 import re
-import sys
 import warnings
 from datetime import datetime
 from typing import TYPE_CHECKING, Callable, List, Optional, Sequence, Set, Union
@@ -27,12 +26,7 @@ from typing import TYPE_CHECKING, Callable, List, Optional, Sequence, Set, Union
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
-
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
+from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.sensors.base import BaseSensorOperator, poke_mode_only
@@ -112,12 +106,13 @@ class S3KeySensor(BaseSensorOperator):
         """
         if self.wildcard_match:
             prefix = re.split(r'[\[\*\?]', key, 1)[0]
-            files = self.get_hook().get_file_metadata(prefix, bucket_name)
-            if len(files) == 0:
+            keys = self.get_hook().get_file_metadata(prefix, bucket_name)
+            key_matches = [k for k in keys if fnmatch.fnmatch(k['Key'], key)]
+            if len(key_matches) == 0:
                 return False
 
             # Reduce the set of metadata to size only
-            files = list(map(lambda f: {'Size': f['Size']}, files))
+            files = list(map(lambda f: {'Size': f['Size']}, key_matches))
         else:
             obj = self.get_hook().head_object(key, bucket_name)
             if obj is None:
@@ -155,7 +150,7 @@ class S3KeySizeSensor(S3KeySensor):
     ):
         warnings.warn(
             """
-            S3PrefixSensor is deprecated.
+            S3KeySizeSensor is deprecated.
             Please use `airflow.providers.amazon.aws.sensors.s3.S3KeySensor`.
             """,
             DeprecationWarning,
@@ -341,8 +336,7 @@ class S3PrefixSensor(S3KeySensor):
             stacklevel=2,
         )
 
-        self.prefix = prefix
-        prefixes = [self.prefix] if isinstance(self.prefix, str) else self.prefix
+        prefixes = [prefix] if isinstance(prefix, str) else prefix
         keys = [pref if pref.endswith(delimiter) else pref + delimiter for pref in prefixes]
 
         super().__init__(bucket_key=keys, **kwargs)
