@@ -18,12 +18,13 @@
 """Reads and then deletes the message from SQS queue"""
 import json
 import warnings
-from typing import TYPE_CHECKING, Any, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Collection, List, Optional, Sequence
 
 from jsonpath_ng import parse
 from typing_extensions import Literal
 
 from airflow.exceptions import AirflowException
+from airflow.providers.amazon.aws.hooks.base_aws import BaseAwsConnection
 from airflow.providers.amazon.aws.hooks.sqs import SqsHook
 from airflow.sensors.base import BaseSensorOperator
 
@@ -34,16 +35,21 @@ if TYPE_CHECKING:
 class SqsSensor(BaseSensorOperator):
     """
     Get messages from an Amazon SQS queue and then delete the messages from the queue.
-    If deletion of messages fails an AirflowException is thrown. Otherwise, the messages
+    If deletion of messages fails, an AirflowException is thrown. Otherwise, the messages
     are pushed through XCom with the key ``messages``.
 
+    By default,the sensor performs one and only one SQS call per poke, which limits the result to
+    a maximum of 10 messages. However, the total number of SQS API calls per poke can be controlled
+    by num_batches param.
+
     .. seealso::
         For more information on how to use this sensor, take a look at the guide:
-        :ref:`howto/operator:SqsSensor`
+        :ref:`howto/sensor:SqsSensor`
 
     :param aws_conn_id: AWS connection id
     :param sqs_queue: The SQS queue url (templated)
     :param max_messages: The maximum number of messages to retrieve for each poke (templated)
+    :param num_batches: The number of times the sensor will call the SQS API to receive messages (default: 1)
     :param wait_time_seconds: The time in seconds to wait for receiving messages (default: 1 second)
     :param visibility_timeout: Visibility timeout, a period of time during which
         Amazon SQS prevents other consumers from receiving and processing the message.
@@ -72,6 +78,7 @@ class SqsSensor(BaseSensorOperator):
         sqs_queue,
         aws_conn_id: str = 'aws_default',
         max_messages: int = 5,
+        num_batches: int = 1,
         wait_time_seconds: int = 1,
         visibility_timeout: Optional[int] = None,
         message_filtering: Optional[Literal["literal", "jsonpath"]] = None,
@@ -84,6 +91,7 @@ class SqsSensor(BaseSensorOperator):
         self.sqs_queue = sqs_queue
         self.aws_conn_id = aws_conn_id
         self.max_messages = max_messages
+        self.num_batches = num_batches
         self.wait_time_seconds = wait_time_seconds
         self.visibility_timeout = visibility_timeout
 
@@ -104,15 +112,13 @@ class SqsSensor(BaseSensorOperator):
 
         self.hook: Optional[SqsHook] = None
 
-    def poke(self, context: 'Context'):
+    def poll_sqs(self, sqs_conn: BaseAwsConnection) -> Collection:
         """
-        Check for message on subscribed queue and write to xcom the message with key ``messages``
+        Poll SQS queue to retrieve messages.
 
-        :param context: the context object
-        :return: ``True`` if message is available or ``False``
+        :param sqs_conn: SQS connection
+        :return: A list of messages retrieved from SQS
         """
-        sqs_conn = self.get_hook().get_conn()
-
         self.log.info('SqsSensor checking for message on queue: %s', self.sqs_queue)
 
         receive_message_kwargs = {
@@ -126,7 +132,7 @@ class SqsSensor(BaseSensorOperator):
         response = sqs_conn.receive_message(**receive_message_kwargs)
 
         if "Messages" not in response:
-            return False
+            return []
 
         messages = response['Messages']
         num_messages = len(messages)
@@ -136,28 +142,47 @@ class SqsSensor(BaseSensorOperator):
             messages = self.filter_messages(messages)
             num_messages = len(messages)
             self.log.info("There are %d messages left after filtering", num_messages)
+        return messages
 
-        if not num_messages:
+    def poke(self, context: 'Context'):
+        """
+        Check subscribed queue for messages and write them to xcom with the ``messages`` key.
+
+        :param context: the context object
+        :return: ``True`` if message is available or ``False``
+        """
+        sqs_conn = self.get_hook().get_conn()
+
+        message_batch: List[Any] = []
+
+        # perform multiple SQS call to retrieve messages in series
+        for _ in range(self.num_batches):
+            messages = self.poll_sqs(sqs_conn=sqs_conn)
+
+            if not len(messages):
+                continue
+
+            message_batch.extend(messages)
+
+            if self.delete_message_on_reception:
+
+                self.log.info("Deleting %d messages", len(messages))
+
+                entries = [
+                    {'Id': message['MessageId'], 'ReceiptHandle': message['ReceiptHandle']}
+                    for message in messages
+                ]
+                response = sqs_conn.delete_message_batch(QueueUrl=self.sqs_queue, Entries=entries)
+
+                if 'Successful' not in response:
+                    raise AirflowException(
+                        'Delete SQS Messages failed ' + str(response) + ' for messages ' + str(messages)
+                    )
+        if not len(message_batch):
             return False
 
-        if not self.delete_message_on_reception:
-            context['ti'].xcom_push(key='messages', value=messages)
-            return True
-
-        self.log.info("Deleting %d messages", num_messages)
-
-        entries = [
-            {'Id': message['MessageId'], 'ReceiptHandle': message['ReceiptHandle']} for message in messages
-        ]
-        response = sqs_conn.delete_message_batch(QueueUrl=self.sqs_queue, Entries=entries)
-
-        if 'Successful' in response:
-            context['ti'].xcom_push(key='messages', value=messages)
-            return True
-        else:
-            raise AirflowException(
-                'Delete SQS Messages failed ' + str(response) + ' for messages ' + str(messages)
-            )
+        context['ti'].xcom_push(key='messages', value=message_batch)
+        return True
 
     def get_hook(self) -> SqsHook:
         """Create and return an SqsHook"""
