@@ -27,9 +27,9 @@ from typing_extensions import Literal
 
 from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
-from airflow.hooks.dbapi import DbApiHook
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
+from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -51,7 +51,11 @@ FILE_OPTIONS_MAP = {
 
 class SqlToS3Operator(BaseOperator):
     """
-    Saves data from an specific SQL query into a file in S3.
+    Saves data from a specific SQL query into a file in S3.
+
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:SqlToS3Operator`
 
     :param query: the sql query to be executed. If you want to execute a file, place the absolute path of it,
         ending with .sql extension. (templated)
